@@ -11,7 +11,7 @@ use Readonly;
 Readonly our $COL_MESSAGE  => 3;
 Readonly our $COL_CHECKBOX => 4;
 
-our $VERSION = '2.2.0';
+our $VERSION = '2.2.1';
 
 sub INIT_INSTANCE {
     my $self = shift;
@@ -61,7 +61,7 @@ sub add_message {
         2, $self->{grid_rows}, 1, 1 );
     my $view   = Gtk3::TextView->new;
     my $buffer = $view->get_buffer;
-    $options{text} =~ s/\s$//xsm;
+    $options{text} =~ s/\s+$//xsm;
     $buffer->set_text( $options{text} );
     $view->set_editable(FALSE);
     $view->set_wrap_mode('word-char');
